@@ -1,6 +1,8 @@
 '''
  ddrlib - Collection of functions used in DDR-Python scripts
 
+ *** Version: ddr-python 1.0.10 - Add continous execution option to ddr_nc_get_trigger, ddr_show_trigger
+ 
  ddrlib functions interact with device management interfaces including
  NETCONF, ssh, cli, NETCONF RFC5277 notificaitons.
  Scripts using ddrlib functions can perform multiple operations including:
@@ -242,7 +244,7 @@ def ddr_nc_notify(device, access_type, triggers, return_response, debug_flag=Fal
     #
     # connect to passwordless NETCONF and create a subscription to the snmpevents stream
     #
-      if access_type == 'loc':
+      if (access_type == 'loc' or access_type == 'cli'):
     #
     # NETCONF connection to device for get operation using public key auth
     #
@@ -323,7 +325,7 @@ def ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcou
             :param relate: logical comparision relation "operator.xx" where xx: ne, eq, gt, lt, ge, le
             :param test_value: Value to compare
             :param interval: Time in seconds between testing the value
-            :param retries: Number of times to try before exiting, -1 to continue until the condition is found or script terminated
+            :param retries: Number of times to try before exiting, 0 to continue until the condition is found or script terminated
             :param debug_flag: True to enable debug output for this call, False no debug output (default)
         
         Usage::
@@ -347,22 +349,22 @@ def ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcou
             command = str(cmdline)
           else:
             if int(pcount) == 1:
-              command = str(show_template) + " {}".format(str(par1))
+              command = str(show_template).format(str(par1))
             elif int(pcount) == 2:
-              command = str(show_template) + " {} {}".format(str(par1), str(par2))
+              command = str(show_template).format(str(par1), str(par2))
             elif int(pcount) == 3:
-              command = str(show_template) + " {} {} {}".format(str(par1), str(par2), str(par3))
+              command = str(show_template).format(str(par1), str(par2), str(par3))
         #
         # Loop for a maximum of retries times to test value
         #
           ddr_debug_msg(debug_flag, f"ddr_show_trigger: command: " + str(command))
 
           condition_met = False
-          test_count = 1
+          test_count = 0
           while (test_count <= retries) and (condition_met == False):
             test_count = test_count + 1
-            if retries == -1:
-              test_count = 1 # Loop until condition found or script terminated
+            if retries == 0:
+              test_count = 0 # Loop until condition found or script terminated
         #
         # If access-type is cli use the Python CLI package to run command
         #
@@ -436,7 +438,7 @@ def ddr_nc_get_trigger(device, access_type, xpath, pcount, par1, par2, par3, lea
         :param relate: logical comparision relation "operator.xx" where xx: ne, eq, gt, lt, ge, le
         :param test_value: Value to compare
         :param interval: Time in seconds between testing the value
-        :param retries: Number of times to try before exiting
+        :param retries: Number of times to try before exiting, 0 to run until triggered or script aborted
         :param debug_flag: True to enable debug output for this call, False no debug output (default)
         
         Usage::
@@ -463,12 +465,12 @@ def ddr_nc_get_trigger(device, access_type, xpath, pcount, par1, par2, par3, lea
     #
     # Test for the parameter value retries times waiting interval seconds between tries
     #
-      test_count = 1
+      test_count = 0
       condition_met = False
       while (test_count <= retries) and (condition_met == False):
         test_count = test_count + 1
-        if retries == -1:
-          test_count = 1 # Loop until condition found or script terminated
+        if retries == 0:
+          test_count = 0 # Loop until condition found or script terminated
 
         get_value = ddr_nc_get(device, access_type, command, leafs, True, debug_flag)
         ddr_debug_msg(debug_flag, f"ddr_nc_get_trigger get_values: {str(get_value)}")
@@ -486,9 +488,9 @@ def ddr_nc_get_trigger(device, access_type, xpath, pcount, par1, par2, par3, lea
             ddr_debug_msg(debug_flag, f"ddr_nc_get_trigger: wait seconds and test again: {str(interval)}")
             time.sleep(interval)
     #
-    # if the trigger condition does not occur, return "none"
+    # if the trigger condition does not occur, return None
     #
-      return "none"
+      return None
 
     except Exception as e:
       ddr_error_msg(f"ddr_nc_get_trigger Exception: {str(e)}")
@@ -525,7 +527,7 @@ def ddr_nc_get(device, access_type, xpath, leafs, return_response, debug_flag=Fa
             :raises none:
     """
     try:
-      if access_type == 'loc':
+      if (access_type == 'loc' or access_type == 'cli'):
     #
     # NETCONF connection to device for get operation using public key auth
     #
@@ -619,7 +621,7 @@ def ddr_nc_get_config(device, access_type, xpath, leaf, return_response, debug_f
             :raises none:
     """
     try:
-      if access_type == 'loc':
+      if (access_type == 'loc' or access_type == 'cli'):
     #
     # NETCONF connection to device for get operation using public key auth
     #
@@ -652,7 +654,7 @@ def ddr_nc_get_config(device, access_type, xpath, leaf, return_response, debug_f
         if return_response:
           return str(get_result)
         else:
-          return none
+          return None
       
       else:
         nodes = xml.dom.minidom.parseString(get_result.xml).getElementsByTagName(leaf)
@@ -701,7 +703,7 @@ def ddr_nc_edit_config(device, access_type, datastore, commit, xpath, return_res
     #
     # NETCONF connection to device for edit_config operation
     #
-      if access_type == 'loc':
+      if (access_type == 'loc' or access_type == 'cli'):
     #
     # NETCONF connection to device for get operation using public key auth
     #
@@ -1267,7 +1269,7 @@ def ddr_show_parameter_all(device, access_type, genie_parser_name, show_template
     # parse the response to get the test leaf value
     #
           parser = genie_str_to_class(genie_parser_name)
-          dictionary = parser.cli(output=response)
+          dictionary = parser.parse(output=response)
           ddr_debug_msg(debug_flag, f"ddr_show_parameter_all: parser dictionary: {str(dictionary)}")
           return dictionary
 
